==> Paws-0.43.tar.gz: Paws-0.43/lib/Paws/EC2/CreateLocalGatewayRouteTableVpcAssociation.pm <==

package Paws::EC2::CreateLocalGatewayRouteTableVpcAssociation;
  use Moose;
  has DryRun => (is => 'ro', isa => 'Bool');
  has LocalGatewayRouteTableId => (is => 'ro', isa => 'Str', required => 1);
  has VpcId => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'CreateLocalGatewayRouteTableVpcAssociation');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::EC2::CreateLocalGatewayRouteTableVpcAssociationResult');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::EC2::CreateLocalGatewayRouteTableVpcAssociation - Arguments for method CreateLocalGatewayRouteTableVpcAssociation on L<Paws::EC2>

=head1 DESCRIPTION

This class represents the parameters used for calling the method CreateLocalGatewayRouteTableVpcAssociation on the
L<Amazon Elastic Compute Cloud|Paws::EC2> service. Use the attributes of this class
as arguments to method CreateLocalGatewayRouteTableVpcAssociation.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to CreateLocalGatewayRouteTableVpcAssociation.

=head1 SYNOPSIS

    my $ec2 = Paws->service('EC2');
    my $CreateLocalGatewayRouteTableVpcAssociationResult =
      $ec2->CreateLocalGatewayRouteTableVpcAssociation(
      LocalGatewayRouteTableId => 'MyLocalGatewayRoutetableId',
      VpcId                    => 'MyVpcId',
      DryRun                   => 1,                              # OPTIONAL
      );

    # Results:
    my $LocalGatewayRouteTableVpcAssociation =
      $CreateLocalGatewayRouteTableVpcAssociationResult
      ->LocalGatewayRouteTableVpcAssociation;

# Returns a L<Paws::EC2::CreateLocalGatewayRouteTableVpcAssociationResult> object.

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/ec2/CreateLocalGatewayRouteTableVpcAssociation>

=head1 ATTRIBUTES


=head2 DryRun => Bool

Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response. If
you have the required permissions, the error response is
C<DryRunOperation>. Otherwise, it is C<UnauthorizedOperation>.



=head2 B<REQUIRED> LocalGatewayRouteTableId => Str

The ID of the local gateway route table.



=head2 B<REQUIRED> VpcId => Str

The ID of the VPC.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method CreateLocalGatewayRouteTableVpcAssociation in L<Paws::EC2>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut

==> Paws-0.44.tar.gz: Paws-0.44/lib/Paws/EC2/CreateLocalGatewayRouteTableVpcAssociation.pm <==

package Paws::EC2::CreateLocalGatewayRouteTableVpcAssociation;
  use Moose;
  has DryRun => (is => 'ro', isa => 'Bool');
  has LocalGatewayRouteTableId => (is => 'ro', isa => 'Str', required => 1);
  has TagSpecifications => (is => 'ro', isa => 'ArrayRef[Paws::EC2::TagSpecification]', traits => ['NameInRequest'], request_name => 'TagSpecification' );
  has VpcId => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'CreateLocalGatewayRouteTableVpcAssociation');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::EC2::CreateLocalGatewayRouteTableVpcAssociationResult');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::EC2::CreateLocalGatewayRouteTableVpcAssociation - Arguments for method CreateLocalGatewayRouteTableVpcAssociation on L<Paws::EC2>

=head1 DESCRIPTION

This class represents the parameters used for calling the method CreateLocalGatewayRouteTableVpcAssociation on the
L<Amazon Elastic Compute Cloud|Paws::EC2> service. Use the attributes of this class
as arguments to method CreateLocalGatewayRouteTableVpcAssociation.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to CreateLocalGatewayRouteTableVpcAssociation.

=head1 SYNOPSIS

    my $ec2 = Paws->service('EC2');
    my $CreateLocalGatewayRouteTableVpcAssociationResult =
      $ec2->CreateLocalGatewayRouteTableVpcAssociation(
      LocalGatewayRouteTableId => 'MyLocalGatewayRoutetableId',
      VpcId                    => 'MyVpcId',
      DryRun                   => 1,                              # OPTIONAL
      TagSpecifications        => [
        {
          ResourceType => 'client-vpn-endpoint'
          , # values: client-vpn-endpoint, customer-gateway, dedicated-host, dhcp-options, egress-only-internet-gateway, elastic-ip, elastic-gpu, export-image-task, export-instance-task, fleet, fpga-image, host-reservation, image, import-image-task, import-snapshot-task, instance, internet-gateway, key-pair, launch-template, local-gateway-route-table-vpc-association, natgateway, network-acl, network-interface, network-insights-analysis, network-insights-path, placement-group, reserved-instances, route-table, security-group, snapshot, spot-fleet-request, spot-instances-request, subnet, traffic-mirror-filter, traffic-mirror-session, traffic-mirror-target, transit-gateway, transit-gateway-attachment, transit-gateway-connect-peer, transit-gateway-multicast-domain, transit-gateway-route-table, volume, vpc, vpc-peering-connection, vpn-connection, vpn-gateway, vpc-flow-log; OPTIONAL
          Tags => [
            {
              Key   => 'MyString',    # OPTIONAL
              Value => 'MyString',    # OPTIONAL
            },
            ...
          ],    # OPTIONAL
        },
        ...
      ],    # OPTIONAL
      );

    # Results:
    my $LocalGatewayRouteTableVpcAssociation =
      $CreateLocalGatewayRouteTableVpcAssociationResult
      ->LocalGatewayRouteTableVpcAssociation;

# Returns a L<Paws::EC2::CreateLocalGatewayRouteTableVpcAssociationResult> object.

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/ec2/CreateLocalGatewayRouteTableVpcAssociation>

=head1 ATTRIBUTES


=head2 DryRun => Bool

Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response. If
you have the required permissions, the error response is
C<DryRunOperation>. Otherwise, it is C<UnauthorizedOperation>.



=head2 B<REQUIRED> LocalGatewayRouteTableId => Str

The ID of the local gateway route table.



=head2 TagSpecifications => ArrayRef[L<Paws::EC2::TagSpecification>]

The tags to assign to the local gateway route table VPC association.



=head2 B<REQUIRED> VpcId => Str

The ID of the VPC.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method CreateLocalGatewayRouteTableVpcAssociation in L<Paws::EC2>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut
